import * as vscode from 'vscode';
import { GitService } from './GitService';

export class GViewProvider implements vscode.WebviewViewProvider {
  public static readonly viewType = "gitcommitfilter.view";

  private _view?: vscode.WebviewView;

  constructor(
    private context: vscode.ExtensionContext,
    private readonly _gitService: GitService
  ) {}

  public resolveWebviewView(
    webviewView: vscode.WebviewView,
    context: vscode.WebviewViewResolveContext
  ) {
    webviewView.webview.options = { enableScripts: true };
    this._view = webviewView;
    console.log("resolveWebviewView:------------");
    webviewView.webview.html = this.generateHtml(webviewView);

    // 添加事件监听器
    webviewView.webview.onDidReceiveMessage(message => {
      switch (message.command) {
        case 'filterCommits':
          const filterText = message.text;
          this.filterCommits(filterText);
          return;
      }
    }, undefined, this.context.subscriptions);
  }

  generateHtml(webviewView: vscode.WebviewView) {
    return `
    <!DOCTYPE html>
    <html lang="en">
    <head>
        <meta charset="UTF-8">
        <meta name="viewport" content="width=device-width, initial-scale=1.0">
        <title>Git Commit Filter</title>
        <style>
            body {
                font-family: var(--vscode-font-family);
                color: var(--vscode-foreground);
                background-color: var(--vscode-editor-background);
                padding: 20px;
                margin: 0;
            }

            input[type="text"] {
                width: 100%;
                padding: 8px;
                margin-bottom: 10px;
                background-color: var(--vscode-input-background);
                color: var(--vscode-input-foreground);
                border: 1px solid var(--vscode-input-border);
            }

            button {
                padding: 8px 16px;
                background-color: var(--vscode-button-background);
                color: var(--vscode-button-foreground);
                border: 1px solid var(--vscode-button-border);
                cursor: pointer;
            }

            button:hover {
                background-color: var(--vscode-button-hoverBackground);
            }

            .commit {
                margin-bottom: 10px;
            }
        </style>
    </head>
    <body>
        <input type="text" id="commitFilter" placeholder="Enter commit message to filter">
        <button id="filterButton">过滤</button>
        <div id="commits"></div>
        <script>
            const vscode = acquireVsCodeApi();

            document.getElementById('filterButton').addEventListener('click', () => {
                const filterText = document.getElementById('commitFilter').value;
                vscode.postMessage({ command: 'filterCommits', text: filterText });
            });

            function updateCommits(commits) {
                const commitsDiv = document.getElementById('commits');
                commitsDiv.innerHTML = '';
                commits.forEach(commit => {
                    const commitDiv = document.createElement('div');
                    commitDiv.className = 'commit';
                    commitDiv.textContent = commit.message;
                    commitsDiv.appendChild(commitDiv);
                });
            }

            // 初始加载commits
            vscode.postMessage({ command: 'filterCommits', text: '' });
        </script>
    </body>
    </html>
    `;
  }

  private filterCommits(filterText: string) {
    if (this._view) {
      const commits = this._gitService.getFilteredCommits(filterText);
      this._view.webview.postMessage({ command: 'updateCommits', commits: commits });
    }
  }
}